import pytest

from gso.products.product_types.geant_ip import GeantIP
from test.workflows import assert_complete, extract_state, run_workflow


@pytest.mark.workflow()
def test_migrate_geant_ip_success(
    faker, edge_port_subscription_factory, partner_factory, geant_ip_subscription_factory
):
    partner = partner_factory()
    subscription_id = geant_ip_subscription_factory(partner=partner)
    new_edge_port_1 = edge_port_subscription_factory(partner=partner)
    new_edge_port_2 = edge_port_subscription_factory(partner=partner)
    subscription = GeantIP.from_subscription(subscription_id)

    form_input_data = [
        {"subscription_id": subscription_id},
        {
            "tt_number": faker.tt_number(),
            "edge_port_selection": [
                {
                    "old_edge_port": subscription.geant_ip.geant_ip_ap_list[0].geant_ip_sbp.edge_port.description,
                    "new_edge_port": new_edge_port_1,
                },
                {
                    "old_edge_port": subscription.geant_ip.geant_ip_ap_list[1].geant_ip_sbp.edge_port.description,
                    "new_edge_port": new_edge_port_2,
                },
            ],
        },
    ]

    result, _, _ = run_workflow("migrate_geant_ip", form_input_data)

    assert_complete(result)
    state = extract_state(result)
    subscription = GeantIP.from_subscription(state["subscription_id"])
    assert subscription.insync
    assert len(subscription.geant_ip.geant_ip_ap_list) == 2
    assert (
        str(subscription.geant_ip.geant_ip_ap_list[0].geant_ip_sbp.edge_port.owner_subscription_id) == new_edge_port_1
    )
    assert (
        str(subscription.geant_ip.geant_ip_ap_list[1].geant_ip_sbp.edge_port.owner_subscription_id) == new_edge_port_2
    )
